@@ -387,7 +387,7 @@ class WorkflowManager():
         # print("Slider updated", event.value, type(event.value))
         if len(slider) == 4: # a time-slider exists
             for l in self.viewer.layers:
-                if len(l.data.shape) == 4:
+                if (not isinstance(l, (napari.layers.Labels, napari.layers.Image))) or len(l.data.shape):
                     self.invalidate(self.workflow.followers_of(l.name))
 
     def _layer_selection_changed(self, event):
@@ -591,8 +591,8 @@ def _generate_python_code(workflow: Workflow, viewer: napari.Viewer, notebook: b
             viewer = napari.Viewer()
             """).strip()
 
-    if len(viewer.dims.current_step):
-        preamble = "\n\n" + dedent("""            
+    if len(viewer.dims.current_step) > 3:
+        preamble = preamble + "\n\n" + dedent("""            
             # ## A note on processing timelapse data
             # This code was generated to process a single timepoint of a timelapse dataset.
             # To process all time points, you need to program a for-loop as shon here:
